import typing

__version__: str
version_info: typing.Tuple[int, int, int]

def check_version(version: str) -> None: ...
def require_version(namespace: str, version: str) -> None: ...
def require_versions(versions: dict[str, str]) -> None: ...
def get_required_version(namespace: str) -> typing.Optional[str]: ...
def require_foreign(namespace: str, symbol: typing.Optional[str] = None) -> None: ...
def get_option(name: str) -> bool: ...
def disable_legacy_autoinit() -> None: ...
