import typing

from gi.repository import GObject
from typing_extensions import Self

T = typing.TypeVar("T")

class Connection(GObject.GPointer): ...
class MethodInvocation(GObject.GPointer): ...
class Proxy(GObject.Object): ...
class ProxyClass(GObject.GPointer): ...
